<template>
    <div class="bbsl-common-page">
        <div class="bbsl-table-search">
            <el-form v-model="queryParam" label-width="auto">
                <el-row :gutter="10">
                    <el-col :span="5">
                        <el-form-item label="设备编号">
                            <el-input v-model="querys[0].value" clearable placeholder="请输入设备编号" />
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="队员名称">
                            <el-input v-model="querys[1].value" clearable placeholder="请输入队员名称" />
                        </el-form-item>
                    </el-col>
                    <el-col :span="4">
                        <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
                        <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <div ref="contentPanel" class="bbsl-table-content">
            <div ref="btnPanel" class="bbsl-btn-content">
            </div>
            <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
                :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
                :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
                @selection-change="handleSelectionChange">
                <el-table-column fixed type="index" width="55" label="序号" />
                <el-table-column fixed prop="name" label="设备名称" show-overflow-tooltip />
                <el-table-column fixed prop="code" label="设备编号" show-overflow-tooltip />
                <el-table-column fixed prop="memberName" label="绑定队员" show-overflow-tooltip />
                <el-table-column fixed sortable prop="orgName" label="所属部门" show-overflow-tooltip />
                <el-table-column fixed prop="memberPost" label="队员职务" show-overflow-tooltip>
                </el-table-column>
                <el-table-column fixed sortable prop="memberPhone" label="联系方式" show-overflow-tooltip />
                <el-table-column align="right" width="120px" label="操作" :index="999">
                    <template v-slot="{ row }">
                        <el-button v-if="!row.memberId" size="mini" type="primary" @click="bindTeamMember(row)">
                            绑定
                        </el-button>
                        <el-button v-else size="mini" type="danger" @click="handleUntie(row)">
                            解绑
                        </el-button>
                    </template>
                </el-table-column>
            </el-table>
            <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
                :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
                :total="total" @size-change="handleSizeChange" @current-change="handleCurrentChange" />
        </div>
        <TeamDeviceBoundPlayerDialog ref="formModal" @refreshData="refreshData" />
    </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import CmgtDutyJobApi from '@/views/Manage/duty/api/CmgtDutyJobApi'
import equipmentManage from '@/api/device/equipmentManage.js'
import TeamDeviceBoundPlayerDialog from './components/TeamDeviceBoundPlayerDialog'
export default {
    name: 'TeamDeviceBoundPlayer',
    components: {
        TeamDeviceBoundPlayerDialog
    },
    mixins: [TableMixin],
    data() {
        return {
            mapVisible: false,
            url: {
                delete: '/manager/cmgtDutyJob/delete'
            },
            querys: [
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'd.code_',
                    relation: 'AND',
                    value: ''
                },
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'm.NAME_',
                    relation: 'AND',
                    value: ''
                }
            ],
            StshowFormDias: false,
            fuelTypes: [],
            equipmentList: [] // 关联区域列表
        }
    },
    created() {
        this.getEquipmentList()
    },
    mounted() { },
    methods: {
        refreshData() {
            this.loadData()
        },
        bindTeamMember(row) {
            this.$refs.formModal.open(row)
        },
        // 解绑
        handleUntie(row) {
            const { name, memberId, memberName } = row
            this.$confirm(`确认将设备${name}与${memberName}解绑？`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            }).then(() => {
                CmgtDutyJobApi.deviceBindingUnbinding({ memberId, deviceCode: '' }, res => {
                    if (res.state) {
                        this.$message.success('解绑成功！')
                        this.loadData()
                    }
                })
            })
        },
        // 获取关联区域列表
        getEquipmentList() {
            equipmentManage.loadAreaTree({ id: '0' }, res => {
                this.equipmentList = res.value
            })
        },
        // 重置
        clearQuerys() {
            this.querys[0].value = ''
            this.querys[1].value = ''
        },
        // 获取list
        loadData(page) {
            if (page) {
                this.queryParam.pageBean.page = page
            }
            this.loading = true
            this.tableData = []
            this.queryParam.querys = []
            if (this.querys[0].value) {
                this.queryParam.querys.push(this.querys[0])
            }
            if (this.querys[1].value) {
                this.queryParam.querys.push(this.querys[1])
            }
            CmgtDutyJobApi.loadDeviceBoundPlayer(this.queryParam, res => {
                // console.log(res, 'res')
                this.total = res.total
                this.tableData = res.rows
                this.$set(this.tableData)
                this.loading = false
            })
        },
        // 关联设备
        // handleClick(item) {
        //   console.log(item.id)
        //   this.StshowFormDias = true
        // },
        closeStshowForm() {
            this.StshowFormDias = false
        },
        mapConfirm(val, row) {
            // console.log('=======val========', val)
            row.area = val.toString()
            this.loading = true
            CmgtDutyJobApi.editCmgtDutyJob(row, res => {
                this.loading = false
                if (res.state) {
                    this.$notify({
                        type: 'success',
                        message: '设置【' + row.name + '】的岗位区域成功',
                        duration: 2000
                    })
                    this.loadData()
                } else {
                    this.$message.warning(res.message)
                }
            })
        }
    }
}
</script>
<style lang="scss" scoped>
.type-tag {
    margin: 0 2px;
}
</style>